"use strict";
const axios_1 = require("axios");
const mqtt_topping_1 = require("mqtt-topping");
const Logger = require("bunyan");
const QUERY_TIMEOUT = 2000;
const QUERY_RETRY_DELAY = 1000;
async function queryBootstrapData(url) {
    try {
        const response = await axios_1.default.get(url, { timeout: QUERY_TIMEOUT });
        return response.data;
    }
    catch (e) {
        await delay(QUERY_RETRY_DELAY);
        return await queryBootstrapData(url);
    }
}
function delay(time) {
    return new Promise(resolve => setTimeout(resolve, time));
}
function createClientId(serviceId, device) {
    const uuid = Math.random().toString(16).substr(2, 8);
    return `${serviceId}-${device}-${uuid}`;
}
module.exports = async function init(bootstrapUrl, serviceId) {
    const logger = Logger.createLogger({
        name: serviceId,
        level: "debug",
        serializers: { error: Logger.stdSerializers.err }
    });
    logger.info({ bootstrapUrl }, "Retrieving bootstrap data from server");
    const bootstrapData = await queryBootstrapData(bootstrapUrl);
    logger.info(bootstrapData, "Bootstrap data retrieved from server");
    const { device, tcpBrokerUri, httpBrokerUri, configServerUri } = bootstrapData;
    const clientId = createClientId(serviceId, device);
    logger.info({ tcpBrokerUri, httpBrokerUri, clientId }, "Connecting to Broker");
    const mqttClient = mqtt_topping_1.default.connect(tcpBrokerUri, httpBrokerUri, { clientId });
    mqttClient.on("connect", () => { logger.info("Connected to Broker"); });
    mqttClient.on("close", () => { logger.error("Disconnected from Broker"); });
    mqttClient.on("error", () => { logger.error("Error Connecting to Broker"); });
    async function queryConfig(configPath, version = "master") {
        return axios_1.default(`${configServerUri}/${version}/${configPath}`);
    }
    return { logger, mqttClient, queryConfig, bootstrapData };
};
//# sourceMappingURL=main.js.map